@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -37,6 +37,7 @@
 #include "RequestGroup.h"
 #include "Option.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "DownloadHandlerConstants.h"
 #include "File.h"
 #include "PieceStorage.h"
@@ -45,7 +46,12 @@
 #include "ContentTypeRequestGroupCriteria.h"
 #include "Exception.h"
 #include "DownloadContext.h"
-#include "bittorrent_helper.h"
+#include "download_helper.h"
+#include "fmt.h"
+#include "ValueBaseBencodeParser.h"
+#include "DiskWriter.h"
+#include "AbstractSingleDiskAdaptor.h"
+#include "BencodeDiskWriter.h"
 
 namespace aria2 {
 
@@ -63,31 +69,53 @@ BtPostDownloadHandler::BtPostDownloadHandler()
 BtPostDownloadHandler::~BtPostDownloadHandler() {}
 
 void BtPostDownloadHandler::getNextRequestGroups
-(std::deque<SharedHandle<RequestGroup> >& groups,
+(std::vector<SharedHandle<RequestGroup> >& groups,
  RequestGroup* requestGroup)
 {
-  const SharedHandle<Option>& op = requestGroup->getOption();
-  _logger->debug("Generating RequestGroups for Torrent file %s",
-		 requestGroup->getFirstFilePath().c_str());
-  RequestGroupHandle rg(new RequestGroup(op));
-
-  std::string content;
-  try {
-    requestGroup->getPieceStorage()->getDiskAdaptor()->openExistingFile();
-    content = util::toString(requestGroup->getPieceStorage()->getDiskAdaptor());
-    requestGroup->getPieceStorage()->getDiskAdaptor()->closeFile();    
-  } catch(Exception& e) {
-    requestGroup->getPieceStorage()->getDiskAdaptor()->closeFile();
-    throw;
+  A2_LOG_INFO(fmt("Generating RequestGroups for Torrent file %s",
+                  requestGroup->getFirstFilePath().c_str()));
+  SharedHandle<ValueBase> torrent;
+  if(requestGroup->inMemoryDownload()) {
+    const SharedHandle<DiskWriter>& dw =
+      static_pointer_cast<AbstractSingleDiskAdaptor>
+      (requestGroup->getPieceStorage()->getDiskAdaptor())->getDiskWriter();
+    const SharedHandle<bittorrent::BencodeDiskWriter>& bdw =
+      static_pointer_cast<bittorrent::BencodeDiskWriter>(dw);
+    int error = bdw->finalize();
+    if(error == 0) {
+      torrent = bdw->getResult();
+    }
+  } else {
+    std::string content;
+    try {
+      requestGroup->getPieceStorage()->getDiskAdaptor()->openExistingFile();
+      content = util::toString(requestGroup->getPieceStorage()
+                               ->getDiskAdaptor());
+      requestGroup->getPieceStorage()->getDiskAdaptor()->closeFile();
+    } catch(Exception& e) {
+      requestGroup->getPieceStorage()->getDiskAdaptor()->closeFile();
+      throw;
+    }
+    ssize_t error;
+    torrent = bittorrent::ValueBaseBencodeParser().parseFinal
+      (content.c_str(), content.size(), error);
   }
-  SharedHandle<DownloadContext> context(new DownloadContext());
-  context->setDir(requestGroup->getDownloadContext()->getDir());
-  bittorrent::loadFromMemory
-    (content, context, File(requestGroup->getFirstFilePath()).getBasename());
-  rg->setDownloadContext(context);
-  context->setOwnerRequestGroup(rg.get());
-  
-  groups.push_back(rg);
+  if(!torrent) {
+    throw DL_ABORT_EX2("Could not parse BitTorrent metainfo",
+                       error_code::BENCODE_PARSE_ERROR);
+  }
+  std::vector<SharedHandle<RequestGroup> > newRgs;
+  createRequestGroupForBitTorrent(newRgs, requestGroup->getOption(),
+                                  std::vector<std::string>(),
+                                  "",
+                                  torrent);
+  requestGroup->followedBy(newRgs.begin(), newRgs.end());
+  SharedHandle<MetadataInfo> mi =
+    createMetadataInfoFromFirstFileEntry(requestGroup->getDownloadContext());
+  if(mi) {
+    setMetadataInfo(newRgs.begin(), newRgs.end(), mi);
+  }
+  groups.insert(groups.end(), newRgs.begin(), newRgs.end());
 }
 
 } // namespace aria2
