@@ -40,6 +40,7 @@
 #include "DHTMessageTracker.h"
 #include "DHTConnection.h"
 #include "DHTMessage.h"
+#include "DHTQueryMessage.h"
 #include "DHTResponseMessage.h"
 #include "DHTUnknownMessage.h"
 #include "DHTMessageFactory.h"
@@ -50,13 +51,14 @@
 #include "LogFactory.h"
 #include "Logger.h"
 #include "util.h"
-#include "bencode.h"
+#include "bencode2.h"
+#include "fmt.h"
 
 namespace aria2 {
 
-DHTMessageReceiver::DHTMessageReceiver(const SharedHandle<DHTMessageTracker>& tracker):
-  _tracker(tracker),
-  _logger(LogFactory::getInstance())
+DHTMessageReceiver::DHTMessageReceiver
+(const SharedHandle<DHTMessageTracker>& tracker)
+  : tracker_(tracker)
 {}
 
 DHTMessageReceiver::~DHTMessageReceiver() {}
@@ -66,69 +68,77 @@ SharedHandle<DHTMessage> DHTMessageReceiver::receiveMessage()
   std::string remoteAddr;
   uint16_t remotePort;
   unsigned char data[64*1024];
-  ssize_t length = _connection->receiveMessage(data, sizeof(data),
-                                               remoteAddr,
-                                               remotePort);
-  if(length <= 0) {
-    return SharedHandle<DHTMessage>();
-  }
   try {
+    ssize_t length = connection_->receiveMessage(data, sizeof(data),
+                                                 remoteAddr,
+                                                 remotePort);
+    if(length <= 0) {
+      return SharedHandle<DHTMessage>();
+    }
     bool isReply = false;
-    const BDE dict = bencode::decode(data, length);
-    if(dict.isDict()) {
-      const BDE& y = dict[DHTMessage::Y];
-      if(y.isString()) {
-        if(y.s() == DHTResponseMessage::R || y.s() == DHTUnknownMessage::E) {
+    SharedHandle<ValueBase> decoded = bencode2::decode(data, length);
+    const Dict* dict = downcast<Dict>(decoded);
+    if(dict) {
+      const String* y = downcast<String>(dict->get(DHTMessage::Y));
+      if(y) {
+        if(y->s() == DHTResponseMessage::R || y->s() == DHTUnknownMessage::E) {
           isReply = true;
         }
       } else {
-        _logger->info("Malformed DHT message. Missing 'y' key. From:%s:%u",
-                      remoteAddr.c_str(), remotePort);
+        A2_LOG_INFO(fmt("Malformed DHT message. Missing 'y' key. From:%s:%u",
+                        remoteAddr.c_str(), remotePort));
         return handleUnknownMessage(data, sizeof(data), remoteAddr, remotePort);
       }
     } else {
-      _logger->info("Malformed DHT message. This is not a bencoded directory."
-                    " From:%s:%u", remoteAddr.c_str(), remotePort);
+      A2_LOG_INFO(fmt("Malformed DHT message. This is not a bencoded directory."
+                      " From:%s:%u",
+                      remoteAddr.c_str(), remotePort));
       return handleUnknownMessage(data, sizeof(data), remoteAddr, remotePort);
     }
-    SharedHandle<DHTMessage> message;
-    SharedHandle<DHTMessageCallback> callback;
     if(isReply) {
-      std::pair<SharedHandle<DHTMessage>, SharedHandle<DHTMessageCallback> > p =
-        _tracker->messageArrived(dict, remoteAddr, remotePort);
-      message = p.first;
-      callback = p.second;
-      if(message.isNull()) {
+      std::pair<SharedHandle<DHTResponseMessage>,
+                SharedHandle<DHTMessageCallback> > p =
+        tracker_->messageArrived(dict, remoteAddr, remotePort);
+      if(!p.first) {
         // timeout or malicious? message
         return handleUnknownMessage(data, sizeof(data), remoteAddr, remotePort);
       }
+      onMessageReceived(p.first);
+      if(p.second) {
+        p.second->onReceived(p.first);
+      }
+      return p.first;
     } else {
-      message = _factory->createQueryMessage(dict, remoteAddr, remotePort);
-      if(message->getLocalNode() == message->getRemoteNode()) {
+      SharedHandle<DHTQueryMessage> message =
+        factory_->createQueryMessage(dict, remoteAddr, remotePort);
+      if(*message->getLocalNode() == *message->getRemoteNode()) {
         // drop message from localnode
-        _logger->info("Received DHT message from localnode.");
+        A2_LOG_INFO("Received DHT message from localnode.");
         return handleUnknownMessage(data, sizeof(data), remoteAddr, remotePort);
       }
+      onMessageReceived(message);
+      return message;
     }
-    _logger->info("Message received: %s", message->toString().c_str());
-    message->validate();
-    message->doReceivedAction();
-    message->getRemoteNode()->markGood();
-    message->getRemoteNode()->updateLastContact();
-    _routingTable->addGoodNode(message->getRemoteNode());
-    if(!callback.isNull()) {
-      callback->onReceived(message);
-    }
-    return message;
   } catch(RecoverableException& e) {
-    _logger->info("Exception thrown while receiving DHT message.", e);
+    A2_LOG_INFO_EX("Exception thrown while receiving DHT message.", e);
     return handleUnknownMessage(data, sizeof(data), remoteAddr, remotePort);
   }
 }
 
+void DHTMessageReceiver::onMessageReceived
+(const SharedHandle<DHTMessage>& message)
+{
+  A2_LOG_INFO(fmt("Message received: %s", message->toString().c_str()));
+  message->validate();
+  message->doReceivedAction();
+  message->getRemoteNode()->markGood();
+  message->getRemoteNode()->updateLastContact();
+  routingTable_->addGoodNode(message->getRemoteNode());
+}
+
 void DHTMessageReceiver::handleTimeout()
 {
-  _tracker->handleTimeout();
+  tracker_->handleTimeout();
 }
 
 SharedHandle<DHTMessage>
@@ -138,24 +148,24 @@ DHTMessageReceiver::handleUnknownMessage(const unsigned char* data,
                                          uint16_t remotePort)
 {
   SharedHandle<DHTMessage> m =
-    _factory->createUnknownMessage(data, length, remoteAddr, remotePort);
-  _logger->info("Message received: %s", m->toString().c_str());
+    factory_->createUnknownMessage(data, length, remoteAddr, remotePort);
+  A2_LOG_INFO(fmt("Message received: %s", m->toString().c_str()));
   return m;
 }
 
 void DHTMessageReceiver::setConnection(const SharedHandle<DHTConnection>& connection)
 {
-  _connection = connection;
+  connection_ = connection;
 }
 
 void DHTMessageReceiver::setMessageFactory(const SharedHandle<DHTMessageFactory>& factory)
 {
-  _factory = factory;
+  factory_ = factory;
 }
 
 void DHTMessageReceiver::setRoutingTable(const SharedHandle<DHTRoutingTable>& routingTable)
 {
-  _routingTable = routingTable;
+  routingTable_ = routingTable;
 }
 
 } // namespace aria2
