@@ -34,9 +34,8 @@
 /* copyright --> */
 #include "DefaultBtProgressInfoFile.h"
 
-#include <cerrno>
 #include <cstring>
-#include <fstream>
+#include <cstdio>
 
 #include "PieceStorage.h"
 #include "Piece.h"
@@ -52,9 +51,10 @@
 #include "util.h"
 #include "a2io.h"
 #include "DownloadFailureException.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "array_fun.h"
 #include "DownloadContext.h"
+#include "BufferedFile.h"
 #ifdef ENABLE_BITTORRENT
 # include "PeerStorage.h"
 # include "BtRuntime.h"
@@ -66,62 +66,67 @@ namespace aria2 {
 const std::string DefaultBtProgressInfoFile::V0000("0000");
 const std::string DefaultBtProgressInfoFile::V0001("0001");
 
-static std::string createFilename
+namespace {
+std::string createFilename
 (const SharedHandle<DownloadContext>& dctx, const std::string& suffix)
 {
   std::string t = dctx->getBasePath();
   t += suffix;
   return t;
 }
+} // namespace
 
 DefaultBtProgressInfoFile::DefaultBtProgressInfoFile
 (const SharedHandle<DownloadContext>& dctx,
  const PieceStorageHandle& pieceStorage,
- const Option* option):
-  _dctx(dctx),
-  _pieceStorage(pieceStorage),
-  _option(option),
-  _logger(LogFactory::getInstance()),
-  _filename(createFilename(_dctx, getSuffix()))
+ const Option* option)
+  : dctx_(dctx),
+    pieceStorage_(pieceStorage),
+    option_(option),
+    filename_(createFilename(dctx_, getSuffix()))
 {}
 
 DefaultBtProgressInfoFile::~DefaultBtProgressInfoFile() {}
 
 void DefaultBtProgressInfoFile::updateFilename()
 {
-  _filename = createFilename(_dctx, getSuffix());
+  filename_ = createFilename(dctx_, getSuffix());
 }
 
 bool DefaultBtProgressInfoFile::isTorrentDownload()
 {
 #ifdef ENABLE_BITTORRENT
-  return !_btRuntime.isNull();
+  return btRuntime_;
 #else // !ENABLE_BITTORRENT
   return false;
 #endif // !ENABLE_BITTORRENT
 }
 
+#define WRITE_CHECK(fp, ptr, count)                                     \
+  if(fp.write((ptr), (count)) != (count)) {                             \
+    throw DL_ABORT_EX(fmt(EX_SEGMENT_FILE_WRITE, filename_.c_str()));   \
+  }
+
 // Since version 0001, Integers are saved in binary form, network byte order.
 void DefaultBtProgressInfoFile::save()
 {
-  _logger->info(MSG_SAVING_SEGMENT_FILE, _filename.c_str());
-  std::string filenameTemp = _filename+"__temp";
+  A2_LOG_INFO(fmt(MSG_SAVING_SEGMENT_FILE, filename_.c_str()));
+  std::string filenameTemp = filename_;
+  filenameTemp += "__temp";
   {
-    std::ofstream o(filenameTemp.c_str(), std::ios::out|std::ios::binary);
-    if(!o) {
-      throw DL_ABORT_EX(StringFormat(EX_SEGMENT_FILE_WRITE,
-                                     _filename.c_str(), strerror(errno)).str());
+    BufferedFile fp(filenameTemp, BufferedFile::WRITE);
+    if(!fp) {
+      throw DL_ABORT_EX(fmt(EX_SEGMENT_FILE_WRITE, filename_.c_str()));
     }
 #ifdef ENABLE_BITTORRENT
     bool torrentDownload = isTorrentDownload();
 #else // !ENABLE_BITTORRENT
     bool torrentDownload = false;
 #endif // !ENABLE_BITTORRENT
-
     // file version: 16 bits
     // values: '1'
-    char version[] = { 0x00, 0x01 };
-    o.write(version, sizeof(version));
+    char version[] = { 0x00u, 0x01u };
+    WRITE_CHECK(fp, version, sizeof(version));
     // extension: 32 bits
     // If this is BitTorrent download, then 0x00000001
     // Otherwise, 0x00000000
@@ -130,92 +135,75 @@ void DefaultBtProgressInfoFile::save()
     if(torrentDownload) {
       extension[3] = 1;
     }
-    o.write(reinterpret_cast<const char*>(&extension), sizeof(extension));
+    WRITE_CHECK(fp, extension, sizeof(extension));
     if(torrentDownload) {
 #ifdef ENABLE_BITTORRENT
       // infoHashLength:
       // length: 32 bits
-      const unsigned char* infoHash = bittorrent::getInfoHash(_dctx);
+      const unsigned char* infoHash = bittorrent::getInfoHash(dctx_);
       uint32_t infoHashLengthNL = htonl(INFO_HASH_LENGTH);
-      o.write(reinterpret_cast<const char*>(&infoHashLengthNL),
-              sizeof(infoHashLengthNL));
+      WRITE_CHECK(fp, &infoHashLengthNL, sizeof(infoHashLengthNL));
       // infoHash:
-      o.write(reinterpret_cast<const char*>(infoHash), INFO_HASH_LENGTH);
+      WRITE_CHECK(fp, infoHash, INFO_HASH_LENGTH);
 #endif // ENABLE_BITTORRENT
     } else {
       // infoHashLength:
       // length: 32 bits
       uint32_t infoHashLength = 0;
-      o.write(reinterpret_cast<const char*>(&infoHashLength),
-              sizeof(infoHashLength));
+      WRITE_CHECK(fp, &infoHashLength, sizeof(infoHashLength));
     }
     // pieceLength: 32 bits
-    uint32_t pieceLengthNL = htonl(_dctx->getPieceLength());
-    o.write(reinterpret_cast<const char*>(&pieceLengthNL),
-            sizeof(pieceLengthNL));
+    uint32_t pieceLengthNL = htonl(dctx_->getPieceLength());
+    WRITE_CHECK(fp, &pieceLengthNL, sizeof(pieceLengthNL));
     // totalLength: 64 bits
-    uint64_t totalLengthNL = hton64(_dctx->getTotalLength());
-    o.write(reinterpret_cast<const char*>(&totalLengthNL),
-            sizeof(totalLengthNL));
+    uint64_t totalLengthNL = hton64(dctx_->getTotalLength());
+    WRITE_CHECK(fp, &totalLengthNL, sizeof(totalLengthNL));
     // uploadLength: 64 bits
     uint64_t uploadLengthNL = 0;
 #ifdef ENABLE_BITTORRENT
     if(torrentDownload) {
-      TransferStat stat = _peerStorage->calculateStat();
+      TransferStat stat = peerStorage_->calculateStat();
       uploadLengthNL = hton64(stat.getAllTimeUploadLength());
     }
 #endif // ENABLE_BITTORRENT
-    o.write(reinterpret_cast<const char*>(&uploadLengthNL),
-            sizeof(uploadLengthNL));
+    WRITE_CHECK(fp, &uploadLengthNL, sizeof(uploadLengthNL));
     // bitfieldLength: 32 bits
-    uint32_t bitfieldLengthNL = htonl(_pieceStorage->getBitfieldLength());
-    o.write(reinterpret_cast<const char*>(&bitfieldLengthNL),
-            sizeof(bitfieldLengthNL));
+    uint32_t bitfieldLengthNL = htonl(pieceStorage_->getBitfieldLength());
+    WRITE_CHECK(fp, &bitfieldLengthNL, sizeof(bitfieldLengthNL));
     // bitfield
-    o.write(reinterpret_cast<const char*>(_pieceStorage->getBitfield()),
-            _pieceStorage->getBitfieldLength());
+    WRITE_CHECK(fp, pieceStorage_->getBitfield(),
+                pieceStorage_->getBitfieldLength());
     // the number of in-flight piece: 32 bits
     // TODO implement this
-    uint32_t numInFlightPieceNL = htonl(_pieceStorage->countInFlightPiece());
-    o.write(reinterpret_cast<const char*>(&numInFlightPieceNL),
-            sizeof(numInFlightPieceNL));
+    uint32_t numInFlightPieceNL = htonl(pieceStorage_->countInFlightPiece());
+    WRITE_CHECK(fp, &numInFlightPieceNL, sizeof(numInFlightPieceNL));
     std::vector<SharedHandle<Piece> > inFlightPieces;
-    inFlightPieces.reserve(_pieceStorage->countInFlightPiece());
-    _pieceStorage->getInFlightPieces(inFlightPieces);
+    inFlightPieces.reserve(pieceStorage_->countInFlightPiece());
+    pieceStorage_->getInFlightPieces(inFlightPieces);
     for(std::vector<SharedHandle<Piece> >::const_iterator itr =
           inFlightPieces.begin(), eoi = inFlightPieces.end();
         itr != eoi; ++itr) {
       uint32_t indexNL = htonl((*itr)->getIndex());
-      o.write(reinterpret_cast<const char*>(&indexNL), sizeof(indexNL));
+      WRITE_CHECK(fp, &indexNL, sizeof(indexNL));
       uint32_t lengthNL = htonl((*itr)->getLength());
-      o.write(reinterpret_cast<const char*>(&lengthNL), sizeof(lengthNL));
+      WRITE_CHECK(fp, &lengthNL, sizeof(lengthNL));
       uint32_t bitfieldLengthNL = htonl((*itr)->getBitfieldLength());
-      o.write(reinterpret_cast<const char*>(&bitfieldLengthNL),
-              sizeof(bitfieldLengthNL));
-      o.write(reinterpret_cast<const char*>((*itr)->getBitfield()),
-              (*itr)->getBitfieldLength());
+      WRITE_CHECK(fp, &bitfieldLengthNL, sizeof(bitfieldLengthNL));
+      WRITE_CHECK(fp, (*itr)->getBitfield(), (*itr)->getBitfieldLength());
     }
-    o.flush();
-    if(!o) {
-      throw DL_ABORT_EX(StringFormat(EX_SEGMENT_FILE_WRITE,
-                                     _filename.c_str(), strerror(errno)).str());
+    if(fp.close() == EOF) {
+      throw DL_ABORT_EX(fmt(EX_SEGMENT_FILE_WRITE, filename_.c_str()));
     }
-    _logger->info(MSG_SAVED_SEGMENT_FILE);
+    A2_LOG_INFO(MSG_SAVED_SEGMENT_FILE);
   }
-  if(!File(filenameTemp).renameTo(_filename)) {
-    throw DL_ABORT_EX(StringFormat(EX_SEGMENT_FILE_WRITE,
-                                   _filename.c_str(), strerror(errno)).str());
+  if(!File(filenameTemp).renameTo(filename_)) {
+    throw DL_ABORT_EX(fmt(EX_SEGMENT_FILE_WRITE, filename_.c_str()));
   }
 }
 
-#define CHECK_STREAM(in, length)                                        \
-  if(in.gcount() != length) {                                           \
-    throw DL_ABORT_EX(StringFormat(EX_SEGMENT_FILE_READ,                \
-                                   _filename.c_str(),"Unexpected EOF").str()); \
-  }                                                                     \
-  if(!in) {                                                             \
-    throw DL_ABORT_EX(StringFormat(EX_SEGMENT_FILE_READ,                \
-                                   _filename.c_str(), strerror(errno)).str()); \
+#define READ_CHECK(fp, ptr, count)                                      \
+  if(fp.read((ptr), (count)) != (count)) {                              \
+    throw DL_ABORT_EX(fmt(EX_SEGMENT_FILE_READ, filename_.c_str()));    \
   }
 
 // It is assumed that integers are saved as:
@@ -223,15 +211,13 @@ void DefaultBtProgressInfoFile::save()
 // 2) network byte order if version == 0001
 void DefaultBtProgressInfoFile::load() 
 {
-  _logger->info(MSG_LOADING_SEGMENT_FILE, _filename.c_str());
-  std::ifstream in(_filename.c_str(), std::ios::in|std::ios::binary);
-  if(!in) {                                                             \
-    throw DL_ABORT_EX(StringFormat(EX_SEGMENT_FILE_READ,                \
-                                   _filename.c_str(), strerror(errno)).str());
+  A2_LOG_INFO(fmt(MSG_LOADING_SEGMENT_FILE, filename_.c_str()));
+  BufferedFile fp(filename_, BufferedFile::READ);
+  if(!fp) {
+    throw DL_ABORT_EX(fmt(EX_SEGMENT_FILE_READ, filename_.c_str()));
   }
   unsigned char versionBuf[2];
-  in.read(reinterpret_cast<char*>(versionBuf), sizeof(versionBuf));
-  CHECK_STREAM(in, sizeof(versionBuf));
+  READ_CHECK(fp, versionBuf, sizeof(versionBuf));
   std::string versionHex = util::toHex(versionBuf, sizeof(versionBuf));
   int version;
   if(DefaultBtProgressInfoFile::V0000 == versionHex) {
@@ -240,85 +226,73 @@ void DefaultBtProgressInfoFile::load()
     version = 1;
   } else {
     throw DL_ABORT_EX
-      (StringFormat("Unsupported ctrl file version: %s",
-                    versionHex.c_str()).str());
+      (fmt("Unsupported ctrl file version: %s", versionHex.c_str()));
   }
   unsigned char extension[4];
-  in.read(reinterpret_cast<char*>(extension), sizeof(extension));
-  CHECK_STREAM(in, sizeof(extension));
+  READ_CHECK(fp, extension, sizeof(extension));
   bool infoHashCheckEnabled = false;
   if(extension[3]&1 && isTorrentDownload()) {
     infoHashCheckEnabled = true;
-    if(_logger->debug()) {
-      _logger->debug("InfoHash checking enabled.");
-    }
+    A2_LOG_DEBUG("InfoHash checking enabled.");
   }
 
   uint32_t infoHashLength;
-  in.read(reinterpret_cast<char*>(&infoHashLength), sizeof(infoHashLength));
-  CHECK_STREAM(in, sizeof(infoHashLength));
+  READ_CHECK(fp, &infoHashLength, sizeof(infoHashLength));
   if(version >= 1) {
     infoHashLength = ntohl(infoHashLength);
   }
-  if((infoHashLength < 0) ||
-     ((infoHashLength == 0) && infoHashCheckEnabled)) {
-    throw DL_ABORT_EX
-      (StringFormat("Invalid info hash length: %d", infoHashLength).str());
+  if(infoHashLength == 0 && infoHashCheckEnabled) {
+    throw DL_ABORT_EX(fmt("Invalid info hash length: %d", infoHashLength));
   }
   if(infoHashLength > 0) {
     array_ptr<unsigned char> savedInfoHash(new unsigned char[infoHashLength]);
-    in.read(reinterpret_cast<char*>
-            (static_cast<unsigned char*>(savedInfoHash)), infoHashLength);
-    CHECK_STREAM(in, static_cast<int>(infoHashLength));
+    READ_CHECK(fp, static_cast<unsigned char*>(savedInfoHash),
+               infoHashLength);
 #ifdef ENABLE_BITTORRENT
     if(infoHashCheckEnabled) {
-      const unsigned char* infoHash = bittorrent::getInfoHash(_dctx);
+      const unsigned char* infoHash = bittorrent::getInfoHash(dctx_);
       if(infoHashLength != INFO_HASH_LENGTH ||
          memcmp(savedInfoHash, infoHash, INFO_HASH_LENGTH) != 0) {
         throw DL_ABORT_EX
-          (StringFormat("info hash mismatch. expected: %s, actual: %s",
-                        util::toHex(infoHash, INFO_HASH_LENGTH).c_str(),
-                        util::toHex(savedInfoHash, infoHashLength).c_str()
-                        ).str());
+          (fmt("info hash mismatch. expected: %s, actual: %s",
+               util::toHex(infoHash, INFO_HASH_LENGTH).c_str(),
+               util::toHex(savedInfoHash, infoHashLength).c_str()
+               ));
       }
     }
 #endif // ENABLE_BITTORRENT
   }
 
   uint32_t pieceLength;
-  in.read(reinterpret_cast<char*>(&pieceLength), sizeof(pieceLength));
-  CHECK_STREAM(in, sizeof(pieceLength));
+  READ_CHECK(fp, &pieceLength, sizeof(pieceLength));
   if(version >= 1) {
     pieceLength = ntohl(pieceLength);
   }
 
   uint64_t totalLength;
-  in.read(reinterpret_cast<char*>(&totalLength), sizeof(totalLength));
-  CHECK_STREAM(in, sizeof(totalLength));
+  READ_CHECK(fp, &totalLength, sizeof(totalLength));
   if(version >= 1) {
     totalLength = ntoh64(totalLength);
   }
-  if(totalLength != _dctx->getTotalLength()) {
+  if(totalLength != static_cast<uint64_t>(dctx_->getTotalLength())) {
     throw DL_ABORT_EX
-      (StringFormat("total length mismatch. expected: %s, actual: %s",
-                    util::itos(_dctx->getTotalLength()).c_str(),
-                    util::itos(totalLength).c_str()).str());
+      (fmt("total length mismatch. expected: %" PRId64 ", actual: %" PRId64 "",
+           dctx_->getTotalLength(),
+           static_cast<int64_t>(totalLength)));
   }
   uint64_t uploadLength;
-  in.read(reinterpret_cast<char*>(&uploadLength), sizeof(uploadLength));
-  CHECK_STREAM(in, sizeof(uploadLength));
+  READ_CHECK(fp, &uploadLength, sizeof(uploadLength));
   if(version >= 1) {
     uploadLength = ntoh64(uploadLength);
   }
 #ifdef ENABLE_BITTORRENT
   if(isTorrentDownload()) {
-    _btRuntime->setUploadLengthAtStartup(uploadLength);
+    btRuntime_->setUploadLengthAtStartup(uploadLength);
   }
 #endif // ENABLE_BITTORRENT
   // TODO implement the conversion mechanism between different piece length.
   uint32_t bitfieldLength;
-  in.read(reinterpret_cast<char*>(&bitfieldLength), sizeof(bitfieldLength));
-  CHECK_STREAM(in, sizeof(bitfieldLength));
+  READ_CHECK(fp, &bitfieldLength, sizeof(bitfieldLength));
   if(version >= 1) {
     bitfieldLength = ntohl(bitfieldLength);
   }
@@ -326,22 +300,19 @@ void DefaultBtProgressInfoFile::load()
     ((totalLength+pieceLength-1)/pieceLength+7)/8;
   if(expectedBitfieldLength != bitfieldLength) {
     throw DL_ABORT_EX
-      (StringFormat("bitfield length mismatch. expected: %d, actual: %d",
-                    expectedBitfieldLength,
-                    bitfieldLength).str());
+      (fmt("bitfield length mismatch. expected: %d, actual: %d",
+           expectedBitfieldLength,
+           bitfieldLength));
   }
 
   array_ptr<unsigned char> savedBitfield(new unsigned char[bitfieldLength]);
-  in.read(reinterpret_cast<char*>
-          (static_cast<unsigned char*>(savedBitfield)), bitfieldLength);
-  CHECK_STREAM(in, static_cast<int>(bitfieldLength));
-  if(pieceLength == _dctx->getPieceLength()) {
-    _pieceStorage->setBitfield(savedBitfield, bitfieldLength);
+  READ_CHECK(fp, static_cast<unsigned char*>(savedBitfield),
+             bitfieldLength);
+  if(pieceLength == static_cast<uint32_t>(dctx_->getPieceLength())) {
+    pieceStorage_->setBitfield(savedBitfield, bitfieldLength);
 
     uint32_t numInFlightPiece;
-    in.read(reinterpret_cast<char*>(&numInFlightPiece),
-            sizeof(numInFlightPiece));
-    CHECK_STREAM(in, sizeof(numInFlightPiece));
+    READ_CHECK(fp, &numInFlightPiece, sizeof(numInFlightPiece));
     if(version >= 1) {
       numInFlightPiece = ntohl(numInFlightPiece);
     }
@@ -349,95 +320,88 @@ void DefaultBtProgressInfoFile::load()
     inFlightPieces.reserve(numInFlightPiece);
     while(numInFlightPiece--) {
       uint32_t index;
-      in.read(reinterpret_cast<char*>(&index), sizeof(index));
-      CHECK_STREAM(in, sizeof(index));
+      READ_CHECK(fp, &index, sizeof(index));
       if(version >= 1) {
         index = ntohl(index);
       }
-      if(!(index < _dctx->getNumPieces())) {
-        throw DL_ABORT_EX
-          (StringFormat("piece index out of range: %u", index).str());
+      if(!(index < dctx_->getNumPieces())) {
+        throw DL_ABORT_EX(fmt("piece index out of range: %u", index));
       }
       uint32_t length;
-      in.read(reinterpret_cast<char*>(&length), sizeof(length));
-      CHECK_STREAM(in, sizeof(length));
+      READ_CHECK(fp, &length, sizeof(length));
       if(version >= 1) {
         length = ntohl(length);
       }
-      if(!(length <=_dctx->getPieceLength())) {
-        throw DL_ABORT_EX
-          (StringFormat("piece length out of range: %u", length).str());
+      if(!(length <= static_cast<uint32_t>(dctx_->getPieceLength()))) {
+        throw DL_ABORT_EX(fmt("piece length out of range: %u", length));
       }
       SharedHandle<Piece> piece(new Piece(index, length));
       uint32_t bitfieldLength;
-      in.read(reinterpret_cast<char*>(&bitfieldLength),
-              sizeof(bitfieldLength));
-      CHECK_STREAM(in, sizeof(bitfieldLength));
+      READ_CHECK(fp, &bitfieldLength, sizeof(bitfieldLength));
       if(version >= 1) {
         bitfieldLength = ntohl(bitfieldLength);
       }
       if(piece->getBitfieldLength() != bitfieldLength) {
         throw DL_ABORT_EX
-          (StringFormat("piece bitfield length mismatch."
-                        " expected: %u actual: %u",
-                        piece->getBitfieldLength(), bitfieldLength).str());
+          (fmt("piece bitfield length mismatch."
+               " expected: %lu actual: %u",
+               static_cast<unsigned long>(piece->getBitfieldLength()),
+               bitfieldLength));
       }
       array_ptr<unsigned char> pieceBitfield
         (new unsigned char[bitfieldLength]);
-      in.read(reinterpret_cast<char*>
-              (static_cast<unsigned char*>(pieceBitfield)), bitfieldLength);
-      CHECK_STREAM(in, static_cast<int>(bitfieldLength));
+      READ_CHECK(fp, static_cast<unsigned char*>(pieceBitfield),
+                 bitfieldLength);
       piece->setBitfield(pieceBitfield, bitfieldLength);
 
 #ifdef ENABLE_MESSAGE_DIGEST
 
-      piece->setHashAlgo(_dctx->getPieceHashAlgo());
+      piece->setHashType(dctx_->getPieceHashType());
 
 #endif // ENABLE_MESSAGE_DIGEST
         
       inFlightPieces.push_back(piece);
     }
-    _pieceStorage->addInFlightPiece(inFlightPieces);
+    pieceStorage_->addInFlightPiece(inFlightPieces);
   } else {
     uint32_t numInFlightPiece;
-    in.read(reinterpret_cast<char*>(&numInFlightPiece),
-            sizeof(numInFlightPiece));
-    CHECK_STREAM(in, sizeof(numInFlightPiece));
+    READ_CHECK(fp, &numInFlightPiece, sizeof(numInFlightPiece));
     if(version >= 1) {
       numInFlightPiece = ntohl(numInFlightPiece);
     }
     BitfieldMan src(pieceLength, totalLength);
     src.setBitfield(savedBitfield, bitfieldLength);
     if((src.getCompletedLength() || numInFlightPiece) &&
-       !_option->getAsBool(PREF_ALLOW_PIECE_LENGTH_CHANGE)) {
-      throw DOWNLOAD_FAILURE_EXCEPTION
+       !option_->getAsBool(PREF_ALLOW_PIECE_LENGTH_CHANGE)) {
+      throw DOWNLOAD_FAILURE_EXCEPTION2
         ("WARNING: Detected a change in piece length. You can proceed with"
          " --allow-piece-length-change=true, but you may lose some download"
-         " progress.");
+         " progress.",
+         error_code::PIECE_LENGTH_CHANGED);
     }
-    BitfieldMan dest(_dctx->getPieceLength(), totalLength);
+    BitfieldMan dest(dctx_->getPieceLength(), totalLength);
     util::convertBitfield(&dest, &src);
-    _pieceStorage->setBitfield(dest.getBitfield(), dest.getBitfieldLength());
+    pieceStorage_->setBitfield(dest.getBitfield(), dest.getBitfieldLength());
   }
-  _logger->info(MSG_LOADED_SEGMENT_FILE);
+  A2_LOG_INFO(MSG_LOADED_SEGMENT_FILE);
 }
 
 void DefaultBtProgressInfoFile::removeFile()
 {
   if(exists()) {
-    File f(_filename);
+    File f(filename_);
     f.remove();
   }
 }
 
 bool DefaultBtProgressInfoFile::exists()
 {
-  File f(_filename);
+  File f(filename_);
   if(f.isFile()) {
-    _logger->info(MSG_SEGMENT_FILE_EXISTS, _filename.c_str());
+    A2_LOG_INFO(fmt(MSG_SEGMENT_FILE_EXISTS, filename_.c_str()));
     return true;
   } else {
-    _logger->info(MSG_SEGMENT_FILE_DOES_NOT_EXIST, _filename.c_str());
+    A2_LOG_INFO(fmt(MSG_SEGMENT_FILE_DOES_NOT_EXIST, filename_.c_str()));
     return false;
   }
 }
@@ -446,13 +410,13 @@ bool DefaultBtProgressInfoFile::exists()
 void DefaultBtProgressInfoFile::setPeerStorage
 (const SharedHandle<PeerStorage>& peerStorage)
 {
-  _peerStorage = peerStorage;
+  peerStorage_ = peerStorage;
 }
 
 void DefaultBtProgressInfoFile::setBtRuntime
 (const SharedHandle<BtRuntime>& btRuntime)
 {
-  _btRuntime = btRuntime;
+  btRuntime_ = btRuntime;
 }
 #endif // ENABLE_BITTORRENT
 
