@@ -32,21 +32,22 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_PEER_H_
-#define _D_PEER_H_
+#ifndef D_PEER_H
+#define D_PEER_H
 
 #include "common.h"
 
 #include <cassert>
 #include <string>
-#include <vector>
+#include <set>
 #include <algorithm>
 
 #include "SharedHandle.h"
-#include "TimeA2.h"
+#include "TimerA2.h"
 #include "BtConstants.h"
 #include "PeerStat.h"
 #include "a2functional.h"
+#include "Command.h"
 
 namespace aria2 {
 
@@ -54,35 +55,38 @@ class PeerSessionResource;
 class BtMessageDispatcher;
 
 class Peer {
-public:
-  std::string ipaddr;
-  // TCP port of the other end of communication.  If _incoming is
+private:
+  std::string ipaddr_;
+  // TCP port of the other end of communication.  If incoming_ is
   // true, then this port is not a port the peer is listening to and
   // we cannot connect to it.
-  uint16_t port;
-private:
-  std::string id;
+  uint16_t port_;
 
-  int32_t _cuid;
+  std::string id_;
 
-  unsigned char _peerId[PEER_ID_LENGTH];
+  cuid_t cuid_;
 
-  Time _firstContactTime;
+  unsigned char peerId_[PEER_ID_LENGTH];
 
-  Time _badConditionStartTime;
+  Timer firstContactTime_;
 
-  bool _seeder;
+  Timer badConditionStartTime_;
 
-  PeerSessionResource* _res;
+  bool seeder_;
+
+  PeerSessionResource* res_;
 
   // If true, port is assumed not to be a listening port.
-  bool _incoming;
+  bool incoming_;
 
   // If true, this peer is from local network.
-  bool _localPeer;
+  bool localPeer_;
+
+  // If true, this peer is disconnected gracefully.
+  bool disconnectedGracefully_;
 
   // Before calling updateSeeder(),  make sure that
-  // allocateSessionResource() is called and _res is created.
+  // allocateSessionResource() is called and res_ is created.
   // Otherwise assertion fails.
   void updateSeeder();
 public:
@@ -92,7 +96,7 @@ public:
 
   bool operator==(const Peer& p)
   {
-    return id == p.id;
+    return id_ == p.id_;
   }
   
   bool operator!=(const Peer& p)
@@ -102,63 +106,80 @@ public:
 
   void resetStatus();
 
-  void usedBy(int32_t cuid);
-
-  int32_t usedBy() const
+  const std::string& getIPAddress() const
   {
-    return _cuid;
+    return ipaddr_;
+  }
+
+  uint16_t getPort() const
+  {
+    return port_;
+  }
+
+  void setPort(uint16_t port)
+  {
+    port_ = port;
+  }
+
+  void usedBy(cuid_t cuid);
+
+  cuid_t usedBy() const
+  {
+    return cuid_;
   }
 
   bool unused() const
   {
-    return _cuid == 0;
+    return cuid_ == 0;
   }
 
-  // Returns true iff _res != 0.
+  // Returns true iff res_ != 0.
   bool isActive() const
   {
-    return _res != 0;
+    return res_ != 0;
   }
 
   void setPeerId(const unsigned char* peerId);
 
   const unsigned char* getPeerId() const
   {
-    return _peerId;
+    return peerId_;
   }
 
   bool isSeeder() const
   {
-    return _seeder;
+    return seeder_;
   }
 
   const std::string& getID() const
   {
-    return id;
+    return id_;
   }
 
   void startBadCondition();
 
   bool isGood() const;
 
-  void allocateSessionResource(size_t pieceLength, uint64_t totalLength);
+  void allocateSessionResource(int32_t pieceLength, int64_t totalLength);
+
+  void reconfigureSessionResource(int32_t pieceLength, int64_t totalLength);
 
   void releaseSessionResource();
 
-  const Time& getFirstContactTime() const
+  const Timer& getFirstContactTime() const
   {
-    return _firstContactTime;
+    return firstContactTime_;
   }
 
-  void setFirstContactTime(const Time& time);
+  void setFirstContactTime(const Timer& time);
 
-  const Time& getBadConditionStartTime() const
+  const Timer& getBadConditionStartTime() const
   {
-    return _badConditionStartTime;
+    return badConditionStartTime_;
   }
 
   // Before calling following member functions,  make sure that
-  // allocateSessionResource() is called and _res is created.
+  // allocateSessionResource() is called and res_ is created.
   // Otherwise assertion fails.
 
   // localhost is choking this peer
@@ -196,29 +217,29 @@ public:
 
   void snubbing(bool b);
 
-  void updateUploadLength(size_t bytes);
+  void updateUploadLength(int32_t bytes);
 
-  void updateDownloadLength(size_t bytes);
+  void updateDownloadLength(int32_t bytes);
 
   /**
    * Returns the transfer rate from localhost to remote host.
    */
-  unsigned int calculateUploadSpeed();
+  int calculateUploadSpeed();
 
   /**
    * Returns the transfer rate from remote host to localhost.
    */
-  unsigned int calculateDownloadSpeed();
+  int calculateDownloadSpeed();
 
   /**
    * Returns the number of bytes uploaded to the remote host.
    */
-  uint64_t getSessionUploadLength() const;
+  int64_t getSessionUploadLength() const;
 
   /**
    * Returns the number of bytes downloaded from the remote host.
    */
-  uint64_t getSessionDownloadLength() const;
+  int64_t getSessionDownloadLength() const;
   
   void setBitfield(const unsigned char* bitfield, size_t bitfieldLength);
 
@@ -244,7 +265,7 @@ public:
 
   size_t countPeerAllowedIndexSet() const;
 
-  const std::vector<size_t>& getPeerAllowedIndexSet() const;
+  const std::set<size_t>& getPeerAllowedIndexSet() const;
 
   void addAmAllowedIndex(size_t index);
 
@@ -268,30 +289,40 @@ public:
 
   void setExtension(const std::string& name, uint8_t id);
 
-  const Time& getLastDownloadUpdate() const;
+  const Timer& getLastDownloadUpdate() const;
 
-  const Time& getLastAmUnchoking() const;
+  const Timer& getLastAmUnchoking() const;
 
-  uint64_t getCompletedLength() const;
+  int64_t getCompletedLength() const;
 
   bool isIncomingPeer() const
   {
-    return _incoming;
+    return incoming_;
   }
 
   void setIncomingPeer(bool incoming);
 
   bool isLocalPeer() const
   {
-    return _localPeer;
+    return localPeer_;
   }
 
   void setLocalPeer(bool flag)
   {
-    _localPeer = flag;
+    localPeer_ = flag;
   }
 
-  void setBtMessageDispatcher(const WeakHandle<BtMessageDispatcher>& dpt);
+  bool isDisconnectedGracefully() const
+  {
+    return disconnectedGracefully_;
+  }
+
+  void setDisconnectedGracefully(bool f)
+  {
+    disconnectedGracefully_ = f;
+  }
+
+  void setBtMessageDispatcher(BtMessageDispatcher* dpt);
 
   size_t countOutstandingUpload() const;
 };
@@ -304,4 +335,4 @@ size_t countSeeder(InputIterator first, InputIterator last)
 
 } // namespace aria2
 
-#endif // _D_PEER_H_
+#endif // D_PEER_H
