@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_PEER_CONNECTION_H_
-#define _D_PEER_CONNECTION_H_
+#ifndef D_PEER_CONNECTION_H
+#define D_PEER_CONNECTION_H
 
 #include "common.h"
 
@@ -45,32 +45,40 @@
 
 namespace aria2 {
 
-class Logger;
+class Peer;
 class SocketCore;
 class ARC4Encryptor;
-class ARC4Decryptor;
 
-// The maximum length of payload. Messages beyond that length are
+// The maximum length of buffer. If the message length (including 4
+// bytes length and payload length) is larger than this value, it is
 // dropped.
-#define MAX_PAYLOAD_LEN (16*1024+128)
+#define MAX_BUFFER_CAPACITY (16*1024+128)
 
 class PeerConnection {
 private:
   cuid_t cuid_;
+  SharedHandle<Peer> peer_;
   SharedHandle<SocketCore> socket_;
-  Logger* logger_;
 
+  int msgState_;
+  // The capacity of the buffer resbuf_
+  size_t bufferCapacity_;
+  // The internal buffer of incoming handshakes and messages
   unsigned char* resbuf_;
+  // The number of bytes written in resbuf_
   size_t resbufLength_;
-  size_t currentPayloadLength_;
-  unsigned char lenbuf_[4];
-  size_t lenbufLength_;
+  // The length of message (not handshake) currently receiving
+  uint32_t currentPayloadLength_;
+  // The number of bytes processed in resbuf_
+  size_t resbufOffset_;
+  // The offset in resbuf_ where the 4 bytes message length begins
+  size_t msgOffset_;
 
   SocketBuffer socketBuffer_;
 
   bool encryptionEnabled_;
   SharedHandle<ARC4Encryptor> encryptor_;
-  SharedHandle<ARC4Decryptor> decryptor_;
+  SharedHandle<ARC4Encryptor> decryptor_;
 
   bool prevPeek_;
 
@@ -79,7 +87,10 @@ private:
   ssize_t sendData(const unsigned char* data, size_t length, bool encryption);
 
 public:
-  PeerConnection(cuid_t cuid, const SharedHandle<SocketCore>& socket);
+  PeerConnection
+  (cuid_t cuid,
+   const SharedHandle<Peer>& peer,
+   const SharedHandle<SocketCore>& socket);
 
   ~PeerConnection();
 
@@ -101,7 +112,7 @@ public:
   (unsigned char* data, size_t& dataLength, bool peek = false);
 
   void enableEncryption(const SharedHandle<ARC4Encryptor>& encryptor,
-                        const SharedHandle<ARC4Decryptor>& decryptor);
+                        const SharedHandle<ARC4Encryptor>& decryptor);
 
   void presetBuffer(const unsigned char* data, size_t length);
 
@@ -114,17 +125,27 @@ public:
     return resbuf_;
   }
 
-  unsigned char* detachBuffer()
+  size_t getBufferLength() const
   {
-    unsigned char* detachbuf = resbuf_;
-    resbuf_ = new unsigned char[MAX_PAYLOAD_LEN];
-    return detachbuf;
+    return resbufLength_;
+  }
+
+  // Returns the pointer to the message in wire format.  This method
+  // must be called after receiveMessage() returned true.
+  const unsigned char* getMsgPayloadBuffer() const;
+
+  // Reserves buffer at least minSize. Reallocate memory if current
+  // buffer length < minSize
+  void reserveBuffer(size_t minSize);
+
+  size_t getBufferCapacity()
+  {
+    return bufferCapacity_;
   }
 };
 
 typedef SharedHandle<PeerConnection> PeerConnectionHandle;
-typedef WeakHandle<PeerConnection> PeerConnectionWeakHandle;
 
 } // namespace aria2
 
-#endif // _D_PEER_CONNECTION_H_
+#endif // D_PEER_CONNECTION_H
