@@ -33,7 +33,6 @@
  */
 /* copyright --> */
 #include "UTMetadataPostDownloadHandler.h"
-#include "BDE.h"
 #include "bittorrent_helper.h"
 #include "RequestGroup.h"
 #include "download_helper.h"
@@ -46,38 +45,39 @@
 #include "a2functional.h"
 #include "DiskAdaptor.h"
 #include "PieceStorage.h"
-#include "bencode.h"
+#include "bencode2.h"
 #include "message.h"
 #include "prefs.h"
 #include "Option.h"
+#include "fmt.h"
 
 namespace aria2 {
 
 bool UTMetadataPostDownloadHandler::Criteria::match
 (const RequestGroup* requestGroup) const
 {
-  SharedHandle<DownloadContext> dctx =
+  const SharedHandle<DownloadContext>& dctx =
     requestGroup->getDownloadContext();
   if(dctx->hasAttribute(bittorrent::BITTORRENT)) {
-    const BDE& attrs = dctx->getAttribute(bittorrent::BITTORRENT);
-    if(!attrs.containsKey(bittorrent::METADATA)) {
+    SharedHandle<TorrentAttribute> attrs = bittorrent::getTorrentAttrs(dctx);
+    if(attrs->metadata.empty()) {
       return true;
     }
   }
   return false;
 }
 
-UTMetadataPostDownloadHandler::UTMetadataPostDownloadHandler():
-  _logger(LogFactory::getInstance())
+UTMetadataPostDownloadHandler::UTMetadataPostDownloadHandler()
 {
-  setCriteria(SharedHandle<Criteria>(new Criteria()));
+  SharedHandle<Criteria> cri(new Criteria());
+  setCriteria(cri);
 }
 
 void UTMetadataPostDownloadHandler::getNextRequestGroups
 (std::vector<SharedHandle<RequestGroup> >& groups, RequestGroup* requestGroup)
 {
-  SharedHandle<DownloadContext> dctx = requestGroup->getDownloadContext();
-  const BDE& attrs = dctx->getAttribute(bittorrent::BITTORRENT);
+  const SharedHandle<DownloadContext>& dctx =requestGroup->getDownloadContext();
+  SharedHandle<TorrentAttribute> attrs = bittorrent::getTorrentAttrs(dctx);
   std::string metadata =
     util::toString(requestGroup->getPieceStorage()->getDiskAdaptor());
   std::string torrent = bittorrent::metadata2Torrent(metadata, attrs);
@@ -85,19 +85,25 @@ void UTMetadataPostDownloadHandler::getNextRequestGroups
   if(requestGroup->getOption()->getAsBool(PREF_BT_SAVE_METADATA)) {
     std::string filename =
       util::applyDir(requestGroup->getOption()->get(PREF_DIR),
-                     util::toHex(attrs[bittorrent::INFO_HASH].s())+".torrent");
+                     util::toHex(attrs->infoHash)+".torrent");
     if(util::saveAs(filename, torrent)) {
-      _logger->notice(MSG_METADATA_SAVED, filename.c_str());
+      A2_LOG_NOTICE(fmt(MSG_METADATA_SAVED, filename.c_str()));
     } else {
-      _logger->notice(MSG_METADATA_NOT_SAVED, filename.c_str());
+      A2_LOG_NOTICE(fmt(MSG_METADATA_NOT_SAVED, filename.c_str()));
     }
   }
   if(!requestGroup->getOption()->getAsBool(PREF_BT_METADATA_ONLY)) {
     std::vector<SharedHandle<RequestGroup> > newRgs;
+    // Don't adjust announce URI because it has been done when
+    // RequestGroup is created with magnet URI.
     createRequestGroupForBitTorrent(newRgs, requestGroup->getOption(),
-                                    std::vector<std::string>(), torrent);
-  
+                                    std::vector<std::string>(),
+                                    A2STR::NIL, torrent, false);
     requestGroup->followedBy(newRgs.begin(), newRgs.end());
+    if(requestGroup->getMetadataInfo()) {
+      setMetadataInfo(newRgs.begin(), newRgs.end(),
+                      requestGroup->getMetadataInfo());
+    }
     groups.insert(groups.end(), newRgs.begin(), newRgs.end());
   }
 }
