@@ -49,22 +49,36 @@ class RequestGroup;
 class Option;
 class MetadataInfo;
 class DownloadContext;
-
-const std::set<std::string>& listRequestOptions();
+class UriListParser;
+class ValueBase;
 
 #ifdef ENABLE_BITTORRENT
 // Create RequestGroup object using torrent file specified by
-// torrent-file option.  If non-empty torrentData is specified, then
-// it is used as a content of torrent file instead. If
-// adjustAnnounceUri is true, announce URIs are adjusted using
-// bittorrent::adjustAnnounceUri().  In this function,
+// metaInfoUri, which is treated as local file path. If non-empty
+// torrentData is specified, then it is used as a content of torrent
+// file instead. If adjustAnnounceUri is true, announce URIs are
+// adjusted using bittorrent::adjustAnnounceUri().  In this function,
 // force-sequential is ignored.
 void createRequestGroupForBitTorrent
 (std::vector<SharedHandle<RequestGroup> >& result,
  const SharedHandle<Option>& option,
  const std::vector<std::string>& uris,
+ const std::string& metaInfoUri,
  const std::string& torrentData = "",
  bool adjustAnnounceUri = true);
+
+// Create RequestGroup object using already decoded torrent metainfo
+// structure.  If adjustAnnounceUri is true, announce URIs are
+// adjusted using bittorrent::adjustAnnounceUri().  In this function,
+// force-sequential is ignored.
+void createRequestGroupForBitTorrent
+(std::vector<SharedHandle<RequestGroup> >& result,
+ const SharedHandle<Option>& option,
+ const std::vector<std::string>& uris,
+ const std::string& metaInfoUri,
+ const SharedHandle<ValueBase>& torrent,
+ bool adjustAnnounceUri = true);
+
 #endif // ENABLE_BITTORRENT
 
 #ifdef ENABLE_METALINK
@@ -77,6 +91,26 @@ void createRequestGroupForMetalink
  const std::string& metalinkData = "");
 #endif // ENABLE_METALINK
 
+// Reads one entry from uriListParser and creates RequestGroups from
+// it and store them in result. If the bad entry is found, this
+// function just skips it and reads next entry. If at least one
+// RequestGroup is created successfully, this function returns true
+// and created RequestGroups are stored in result. If no RequestGroup
+// is created and uriListParser reads all input, this function returns
+// false. The option is used as a option template.
+bool createRequestGroupFromUriListParser
+(std::vector<SharedHandle<RequestGroup> >& result,
+ const Option* option,
+ UriListParser* uriListParser);
+
+// Creates UriListParser using given filename.  If filename is "-",
+// then UriListParser is configured to read from standard input.
+// Otherwise, this function first checks file denoted by filename
+// exists.  If it does not exist, this function throws exception.
+// This function returns SharedHandle<UriListParser> object if it
+// succeeds.
+SharedHandle<UriListParser> openUriListParser(const std::string& filename);
+
 // Create RequestGroup objects from reading file specified by input-file option.
 // If the value of input-file option is "-", stdin is used as a input source.
 // Each line is treated as if it is provided in command-line argument.
@@ -112,6 +146,10 @@ void setMetadataInfo
 SharedHandle<MetadataInfo>
 createMetadataInfoFromFirstFileEntry(const SharedHandle<DownloadContext>& dctx);
 
+// Removes option value which is only effective at the first
+// construction time.
+void removeOneshotOption(const SharedHandle<Option>& option);
+
 } // namespace aria2
 
 #endif // D_DOWNLOAD_HELPER_H
