@@ -54,10 +54,8 @@
     "                              once so that N connections total are made\n" \
     "                              simultaneously. The number of connections to the\n" \
     "                              same host is restricted by\n"        \
-    "                              --max-connection-per-server option. Please see -j\n" \
-    "                              and --min-split-size option too.\n"  \
-    "                              Please note that in Metalink download, this\n" \
-    "                              option has no effect and use -C option instead.")
+    "                              --max-connection-per-server option. See also\n" \
+    "                              --min-split-size option.")
 #define TEXT_RETRY_WAIT                                                 \
   _(" --retry-wait=SEC             Set the seconds to wait between retries. \n" \
     "                              With SEC > 0, aria2 will retry download when the\n" \
@@ -139,7 +137,10 @@
     "                              takes almost same time as 'prealloc' and it\n" \
     "                              blocks aria2 entirely until allocation finishes.\n" \
     "                              'falloc' may not be available if your system\n" \
-    "                              doesn't have posix_fallocate() function.")
+    "                              doesn't have posix_fallocate() function.\n" \
+    "                              'trunc' uses ftruncate() system call or\n" \
+    "                              platform-specific counterpart to truncate a file\n" \
+    "                              to a specified length.")
 #define TEXT_NO_FILE_ALLOCATION_LIMIT                                   \
   _(" --no-file-allocation-limit=SIZE No file allocation is made for files whose\n" \
     "                              size is smaller than SIZE.\n"        \
@@ -184,10 +185,18 @@
   _(" --enable-http-pipelining[=true|false] Enable HTTP/1.1 pipelining.")
 #define TEXT_CHECK_INTEGRITY                                            \
   _(" -V, --check-integrity[=true|false] Check file integrity by validating piece\n" \
-    "                              hashes. This option has effect only in BitTorrent\n" \
-    "                              and Metalink downloads with chunk checksums.\n" \
-    "                              Use this option to re-download a damaged portion\n" \
-    "                              of a file. See also --bt-hash-check-seed option.")
+    "                              hashes or a hash of entire file. This option has\n" \
+    "                              effect only in BitTorrent, Metalink downloads\n" \
+    "                              with checksums or HTTP(S)/FTP downloads with\n" \
+    "                              --checksum option. If piece hashes are provided,\n" \
+    "                              this option can detect damaged portions of a file\n" \
+    "                              and re-download them. If a hash of entire file is\n" \
+    "                              provided, hash check is only done when file has\n" \
+    "                              been already download. This is determined by file\n" \
+    "                              length. If hash check fails, file is\n" \
+    "                              re-downloaded from scratch. If both piece hashes\n" \
+    "                              and a hash of entire file are provided, only\n" \
+    "                              piece hashes are used.")
 #define TEXT_BT_HASH_CHECK_SEED                                         \
   _(" --bt-hash-check-seed[=true|false] If true is given, after hash check using\n" \
     "                              --check-integrity option and file is complete,\n" \
@@ -220,11 +229,11 @@
     "                              line of URI. This optional line must start with\n" \
     "                              one or more white spaces and have one option per\n" \
     "                              single line. See INPUT FILE section of man page\n" \
-    "                              for details.")
+    "                              for details. See also --deferred-input option.")
 #define TEXT_MAX_CONCURRENT_DOWNLOADS                                   \
   _(" -j, --max-concurrent-downloads=N Set maximum number of parallel downloads for\n" \
     "                              every static (HTTP/FTP) URL, torrent and metalink.\n" \
-    "                              See also -s and -C options.")
+    "                              See also --split option.")
 #define TEXT_LOAD_COOKIES                                               \
   _(" --load-cookies=FILE          Load Cookies from FILE using the Firefox3 format\n" \
     "                              and Mozilla/Firefox(1.x/2.x)/Netscape format.")
@@ -771,19 +780,6 @@
 #define TEXT_RPC_LISTEN_PORT                                        \
   _(" --rpc-listen-port=PORT       Specify a port number for JSON-RPC/XML-RPC server\n" \
     "                              to listen to.")
-#define TEXT_ENABLE_XML_RPC                                             \
-  _(" --enable-xml-rpc[=true|false] Deprecated. Use --enable-rpc instead.")
-#define TEXT_XML_RPC_MAX_REQUEST_SIZE                                   \
-  _(" --xml-rpc-max-request-size=SIZE Deprecated. Use --rpc-max-request-size\n" \
-    "                              instead.")
-#define TEXT_XML_RPC_USER                               \
-  _(" --xml-rpc-user=USER          Deprecated. Use --rpc-user instead.")
-#define TEXT_XML_RPC_PASSWD                                     \
-  _(" --xml-rpc-passwd=PASSWD      Deprecated. Use --rpc-passwd instead.")
-#define TEXT_XML_RPC_LISTEN_ALL                                         \
-  _(" --xml-rpc-listen-all[=true|false] Deprecated. Use --rpc-listen-all instead.")
-#define TEXT_XML_RPC_LISTEN_PORT                                        \
-  _(" --xml-rpc-listen-port=PORT   Deprecated. Use --rpc-listen-port instead.")
 #define TEXT_SHOW_CONSOLE_READOUT                                       \
   _(" --show-console-readout[=true|false] Show console readout.")
 #define TEXT_METALINK_BASE_URI                  \
@@ -809,10 +805,78 @@
     "                              Please note that aria2 honors\n"     \
     "                              --min-split-size option, so it will be necessary\n" \
     "                              to specify a reasonable value to\n"  \
-    "                              --min-split-size option.")
+    "                              --min-split-size option.\n"          \
+    "                              If 'geom' is given, at the beginning aria2\n" \
+    "                              selects piece which has minimum index like\n" \
+    "                              'inorder', but it exponentially increasingly\n" \
+    "                              keeps space from previously selected piece. This\n" \
+    "                              will reduce the number of establishing connection\n" \
+    "                              and at the same time it will download the\n" \
+    "                              beginning part of the file first. This will be\n" \
+    "                              useful to view movie while downloading it.")
 #define TEXT_TRUNCATE_CONSOLE_READOUT                                   \
   _(" --truncate-console-readout[=true|false] Truncate console readout to fit in\n"\
     "                              a single line.")
 #define TEXT_PAUSE                              \
   _(" --pause[=true|false]         Pause download after added. This option is\n" \
     "                              effective only when --enable-rpc=true is given.")
+#define TEXT_RPC_ALLOW_ORIGIN_ALL                                       \
+  _(" --rpc-allow-origin-all[=true|false] Add Access-Control-Allow-Origin header\n" \
+    "                              field with value '*' to the RPC response.")
+#define TEXT_DOWNLOAD_RESULT                    \
+  _(" --download-result=OPT        This option changes the way \"Download Results\"\n" \
+    "                              is formatted. If OPT is 'default', print GID,\n" \
+    "                              status, average download speed and path/URI. If\n" \
+    "                              multiple files are involved, path/URI of first\n" \
+    "                              requested file is printed and remaining ones are\n" \
+    "                              omitted.\n"                          \
+    "                              If OPT is 'full', print GID, status, average\n" \
+    "                              download speed, percentage of progress and\n" \
+    "                              path/URI. The percentage of progress and\n" \
+    "                              path/URI are printed for each requested file in\n" \
+    "                              each row.")
+#define TEXT_HASH_CHECK_ONLY                    \
+  _(" --hash-check-only[=true|false] If true is given, after hash check using\n" \
+    "                              --check-integrity option, abort download whether\n" \
+    "                              or not download is complete.")
+#define TEXT_CHECKSUM                                                   \
+  _(" --checksum=TYPE=DIGEST       Set checksum. TYPE is hash type. The supported\n" \
+    "                              hash type is listed in \"Hash Algorithms\" in\n" \
+    "                              \"aria2c -v\". DIGEST is hex digest.\n" \
+    "                              For example, setting sha-1 digest looks like\n" \
+    "                              this:\n"                             \
+    "                              sha-1=0192ba11326fe2298c8cb4de616f4d4140213838\n" \
+    "                              This option applies only to HTTP(S)/FTP\n" \
+    "                              downloads.")
+#define TEXT_PIECE_LENGTH                       \
+  _(" --piece-length=LENGTH        Set a piece length for HTTP/FTP downloads. This\n" \
+    "                              is the boundary when aria2 splits a file. All\n" \
+    "                              splits occur at multiple of this length. This\n" \
+    "                              option will be ignored in BitTorrent downloads.\n" \
+    "                              It will be also ignored if Metalink file\n" \
+    "                              contains piece hashes.")
+#define TEXT_STOP_WITH_PROCESS                                          \
+  _(" --stop-with-process=PID      Stop application when process PID is not running.\n" \
+    "                              This is useful if aria2 process is forked from a\n" \
+    "                              parent process. The parent process can fork aria2\n" \
+    "                              with its own pid and when parent process exits\n" \
+    "                              for some reason, aria2 can detect it and shutdown\n" \
+    "                              itself.")
+#define TEXT_DEFERRED_INPUT                     \
+  _(" --deferred-input[=true|false] If true is given, aria2 does not read all URIs\n" \
+    "                              and options from file specified by -i option at\n" \
+    "                              startup, but it reads one by one when it needs\n" \
+    "                              later. This may reduce memory usage if input\n" \
+    "                              file contains a lot of URIs to download.\n" \
+    "                              If false is given, aria2 reads all URIs and\n" \
+    "                              options at startup.")
+#define TEXT_BT_REMOVE_UNSELECTED_FILE                                  \
+  _(" --bt-remove-unselected-file[=true|false] Removes the unselected files when\n" \
+    "                              download is completed in BitTorrent. To\n" \
+    "                              select files, use --select-file option. If\n" \
+    "                              it is not used, all files are assumed to be\n" \
+    "                              selected. Please use this option with care\n" \
+    "                              because it will actually remove files from\n" \
+    "                              your disk.")
+#define TEXT_ENABLE_MMAP                        \
+  _(" --enable-mmap[=true|false]   Map files into memory.")
